/*
 *    GeoTools - The Open Source Java GIS Toolkit
 *    http://geotools.org
 *
 *    (C) 2017, Open Source Geospatial Foundation (OSGeo)
 *
 *    This library is free software; you can redistribute it and/or
 *    modify it under the terms of the GNU Lesser General Public
 *    License as published by the Free Software Foundation;
 *    version 2.1 of the License.
 *
 *    This library is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *    Lesser General Public License for more details.
 */
package org.geotools.jdbc;

/**
 * JDBC callback factory.
 *
 * <p>This interface is used to "inject" callbacks into the various JDBC classes.
 */
public interface JDBCCallbackFactory {

    /** Null callback factory. */
    JDBCCallbackFactory NULL =
            new JDBCCallbackFactory() {
                @Override
                public String getName() {
                    return "null";
                }

                @Override
                public JDBCReaderCallback createReaderCallback() {
                    return JDBCReaderCallback.NULL;
                }

                @Override
                public String toString() {
                    return "null callback";
                }
            };

    /** Callback factory name. */
    String getName();

    /** Creates a callback for {@link JDBCFeatureReader}. */
    JDBCReaderCallback createReaderCallback();
}
